@@ -26,10 +26,16 @@ DNSMASQ="/usr/sbin/dnsmasq"
 #ifconfig bnep0 up
 ifconfig bnep0 $IP_ADDR netmask $NETMASK up
 
+if [ -f $RUNFILE ]
+	     then
+		 kill `cat $RUNFILE`
+		 rm $RUNFILE
+		 fi
 # Setup DNS and DHCP
 if [ "$1" = "lan" ] ; then
 #start-stop-daemon -S -p $RUNFILE -m -b -x $DNSMASQ -- -k -I lo -z -a $IP_ADDR -F $DHCP_RANGE1,$DHCP_RANGE2 -b
-start-stop-daemon -S -p $RUNFILE -m -b -x $DNSMASQ -- -k -i bnep0 -I lo -z -a $IP_ADDR --address=/#/$IP_ADDR -F $DHCP_RANGE1,$DHCP_RANGE2,h6
+#start-stop-daemon -S -p $RUNFILE -m -b -x $DNSMASQ -- -k -i bnep0 -I lo -z -a $IP_ADDR --address=/#/$IP_ADDR -F $DHCP_RANGE1,$DHCP_RANGE2,h6
+start-stop-daemon -S -p $RUNFILE -m -b -x $DNSMASQ --  -z -R -i bnep0 -I lo -h -5 -p 0 -F $DHCP_RANGE1,$DHCP_RANGE2,9999h --dhcp-option=6 --dhcp-option=3
 fi
 
 if [ "$1" = "for" ] ; then
