@@ -13,6 +13,8 @@ class MainWindow;
 }
 class RCQTextEdit;
 class UsbManager;
+class QTextEdit;
+class HelpWindow;
 
 class MainWindow : public QMainWindow
 {
@@ -30,6 +32,10 @@ private:
     QTime downloadTime;
     QFile downfile;
     UsbManager *m_usbmanage;
+    QTextEdit *m_helpwindow;
+    QStringList hfiles;
+    QColor bgtextcolor;
+    QColor textcolor;
 
 protected:
     void closeEvent(QCloseEvent *event);
@@ -195,6 +201,22 @@ private slots:
     void on_pushButton_dnsmasq_clicked();
     void on_pushButton_forward_clicked();
     void on_tabWidget_main_currentChanged(int index);
+    void on_pushButton_help_clicked();
+    void showHelp(QString infofile);
+    void on_pushButton_helpaktion_clicked();
+    void on_listWidget_help_doubleClicked(const QModelIndex &index);
+
+    void on_pushButton_loadfileblip_clicked();
+    void on_pushButton_advset_clicked();
+    void on_checkBox_fontfilter_stateChanged(int arg1);
+    void on_pushButton_bgcolor_clicked();
+    void on_pushButton_viewfontcolor_clicked();
+    void textcolorset(QColor);
+    void bgtextcolorset(QColor);
+
+public slots:
+    void helpaktion_button(bool act, bool forground);
+
 };
 
 #endif // MAINWINDOW_H
